==> eiffelstudio-18.01.10.1424.tar: F_code/C11/xm519.h <==

#ifndef _C11_xm519_
#define _C11_xm519_

#ifdef __cplusplus
extern "C" {
#endif

RTOSHF (EIF_REFERENCE,10055)
static EIF_REFERENCE F1204_10055_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10055(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10056)
static EIF_REFERENCE F1204_10056_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10056(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10057)
static EIF_REFERENCE F1204_10057_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10057(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10058)
static EIF_REFERENCE F1204_10058_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10058(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10059)
static EIF_REFERENCE F1204_10059_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10059(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10060)
static EIF_REFERENCE F1204_10060_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10060(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10061)
static EIF_REFERENCE F1204_10061_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10061(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10062)
static EIF_REFERENCE F1204_10062_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10062(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10063)
static EIF_REFERENCE F1204_10063_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10063(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10064)
static EIF_REFERENCE F1204_10064_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10064(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10065)
static EIF_REFERENCE F1204_10065_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10065(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10066)
static EIF_REFERENCE F1204_10066_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10066(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10067)
static EIF_REFERENCE F1204_10067_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10067(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10068)
static EIF_REFERENCE F1204_10068_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10068(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10069)
static EIF_REFERENCE F1204_10069_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10069(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10070)
static EIF_REFERENCE F1204_10070_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10070(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10071)
static EIF_REFERENCE F1204_10071_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10071(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10072)
static EIF_REFERENCE F1204_10072_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10072(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10073)
static EIF_REFERENCE F1204_10073_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10073(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10074)
static EIF_REFERENCE F1204_10074_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10074(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10075)
static EIF_REFERENCE F1204_10075_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10075(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10076)
static EIF_REFERENCE F1204_10076_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10076(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10077)
static EIF_REFERENCE F1204_10077_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10077(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10078)
static EIF_REFERENCE F1204_10078_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10078(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10079)
static EIF_REFERENCE F1204_10079_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10079(EIF_REFERENCE);
extern void EIF_Minit519(void);

#ifdef __cplusplus
}
#endif

#endif

==> eiffelstudio-18.07.10.1981.tar: F_code/C11/xm519.h <==

#ifndef _C11_xm519_
#define _C11_xm519_

#ifdef __cplusplus
extern "C" {
#endif

RTOSHF (EIF_REFERENCE,10057)
static EIF_REFERENCE F1204_10057_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10057(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10058)
static EIF_REFERENCE F1204_10058_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10058(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10059)
static EIF_REFERENCE F1204_10059_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10059(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10060)
static EIF_REFERENCE F1204_10060_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10060(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10061)
static EIF_REFERENCE F1204_10061_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10061(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10062)
static EIF_REFERENCE F1204_10062_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10062(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10063)
static EIF_REFERENCE F1204_10063_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10063(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10064)
static EIF_REFERENCE F1204_10064_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10064(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10065)
static EIF_REFERENCE F1204_10065_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10065(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10066)
static EIF_REFERENCE F1204_10066_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10066(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10067)
static EIF_REFERENCE F1204_10067_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10067(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10068)
static EIF_REFERENCE F1204_10068_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10068(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10069)
static EIF_REFERENCE F1204_10069_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10069(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10070)
static EIF_REFERENCE F1204_10070_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10070(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10071)
static EIF_REFERENCE F1204_10071_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10071(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10072)
static EIF_REFERENCE F1204_10072_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10072(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10073)
static EIF_REFERENCE F1204_10073_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10073(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10074)
static EIF_REFERENCE F1204_10074_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10074(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10075)
static EIF_REFERENCE F1204_10075_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10075(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10076)
static EIF_REFERENCE F1204_10076_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10076(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10077)
static EIF_REFERENCE F1204_10077_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10077(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10078)
static EIF_REFERENCE F1204_10078_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10078(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10079)
static EIF_REFERENCE F1204_10079_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10079(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10080)
static EIF_REFERENCE F1204_10080_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10080(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,10081)
static EIF_REFERENCE F1204_10081_body(EIF_REFERENCE);
extern EIF_REFERENCE F1204_10081(EIF_REFERENCE);
extern void EIF_Minit519(void);
extern EIF_REFERENCE F1198_9581(EIF_REFERENCE);
extern EIF_REFERENCE F1203_10010(EIF_REFERENCE);
extern EIF_REFERENCE F1203_10023(EIF_REFERENCE);
extern EIF_REFERENCE F1203_10012(EIF_REFERENCE);
extern void F1720_16259(EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE, EIF_INTEGER_32);
RTOSHF(EIF_REFERENCE,9581)
RTOSHF(EIF_REFERENCE,10010)
RTOSHF(EIF_REFERENCE,10023)
RTOSHF(EIF_REFERENCE,10012)

#ifdef __cplusplus
}
#endif

#endif
